@@ -440,6 +440,8 @@ skip_impl = {
     'virNodeDeviceGetAutostart',
     'virDomainSaveParams',
     'virDomainRestoreParams',
+    'virDomainGetAutostartOnce',
+    'virDomainSetThrottleGroup',
 
     'virDomainLxcOpenNamespace',
 
